@@ -71,4 +71,4 @@ def iter_ngrams(__iterator, width: int, wrapper: Callable = tuple, limit: int =
         if width == 2
         else iter(__iterator)
     )
-    return iterator if limit is None else __iter_limit(iterator)
+    return iterator if limit is None else __iter_limit(iterator,limit=limit)
